#  ___________________________________________________________________________
#
#  Pyomo: Python Optimization Modeling Objects
#  Copyright 2017 National Technology and Engineering Solutions of Sandia, LLC
#  Under the terms of Contract DE-NA0003525 with National Technology and
#  Engineering Solutions of Sandia, LLC, the U.S. Government retains certain
#  rights in this software.
#  This software is distributed under the 3-clause BSD License.
#  ___________________________________________________________________________

def load():
    import pyomo.gdp.plugins.bigm
    import pyomo.gdp.plugins.chull
    import pyomo.gdp.plugins.bilinear
    import pyomo.gdp.plugins.gdp_var_mover
    import pyomo.gdp.plugins.cuttingplane
    import pyomo.gdp.plugins.fix_disjuncts
